=====================
Working with Classes
=====================

.. Here is were you specify the content and order of your new book.

.. Each section heading (e.g. "SECTION 1: A Random Section") will be
   a heading in the table of contents. Source files that should be
   generated and included in that section should be placed on individual
   lines, with one line separating the first source filename and the
   :maxdepth: line.

.. Sources can also be included from subfolders of this directory.
   (e.g. "DataStructures/queues.rst").

SECTION 1: Introduction
:::::::::::::::::::::::

This study has four parts.  It will take approximately 50 minutes to complete
the study.  Please do the parts in order and answer questions to the best
of your ability without any outside help. You can stop working on a problem after you worked
on it for about five minutes without solving it.

If you have questions about this study please email Dr. Barbara Ericson at barbarer@umich.edu.

The parts are:

- Pre Survey - Questions about your experience and confidence in computing
- Creating Classes - Learn how to create a class, methods, and objects
- Practice - Practice problems
- Post Test - Post test problems

Click on the link at the end of each page to get to the next part.

What to do next
============================
.. raw:: html

    <p>Click on the following link to take the pre survey : <b><a id="class-survey"> <font size="+2">Pre Survey</font></a></b></p>

.. raw:: html

    <script type="text/javascript" >

      window.history.pushState(null, null, window.location.href);
      window.onpopstate = function () {
          window.history.go(1);
      }

      window.onload = function() {

        a = document.getElementById("class-survey")
        a.href = "class-presurvey.html"
      };

    </script>
